#
# spec file for package python-magic-wormhole
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname magic-wormhole
Name:           python-magic-wormhole
Version:        0.13.0
Release:        1.1
Summary:        Tool for transferring files through a secure channel
License:        MIT
URL:            https://github.com/warner/magic-wormhole
Source:         https://files.pythonhosted.org/packages/source/m/magic-wormhole/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module Automat}
BuildRequires:  %{python_module PyNaCl}
BuildRequires:  %{python_module Twisted}
BuildRequires:  %{python_module attrs >= 19.2.0}
BuildRequires:  %{python_module autobahn}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module humanize}
BuildRequires:  %{python_module magic-wormhole-mailbox-server}
BuildRequires:  %{python_module magic-wormhole-transit-relay}
BuildRequires:  %{python_module noiseprotocol}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module spake2 >= 0.8}
BuildRequires:  %{python_module tqdm >= 4.13.0}
BuildRequires:  %{python_module txtorcon >= 18.0.2}
BuildRequires:  %{pythons}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Automat
Requires:       python-PyNaCl
Requires:       python-Twisted
Requires:       python-attrs >= 19.0.2
Requires:       python-autobahn
Requires:       python-click
Requires:       python-cryptography
Requires:       python-humanize
Requires:       python-six
Requires:       python-spake2 >= 0.8
Requires:       python-tqdm >= 4.13.0
Requires:       python-txtorcon >= 18.0.2
Requires(post): update-alternatives
Requires(preun):update-alternatives
Suggests:       python-magic-wormhole-mailbox-server
Suggests:       python-magic-wormhole-transit-relay
Suggests:       python-noiseprotocol
BuildArch:      noarch
%python_subpackages

%description
This package provides a library and a command-line tool named wormhole,
which makes it possible to get arbitrary-sized files and directories from
one computer to another. The two endpoints are identified by using identical
"wormhole codes": in general, the sending machine generates and displays
the code, which must then be typed into the receiving machine.

%prep
%setup -q -n %{modname}-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/wormhole

%check
%pytest src/wormhole/test -k 'not test_welcome'

%post
%python_install_alternative wormhole

%postun
%python_uninstall_alternative wormhole

%files %{python_files}
%license LICENSE
%doc NEWS.md README.md
%python_alternative %{_bindir}/wormhole
%{python_sitelib}/wormhole
%{python_sitelib}/magic_wormhole-%{version}*-info

%changelog
* Tue Sep 19 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.13.0
- drop python-magic-wormhole-no-mock.patch
  + Python 2.7 support is dropped
  + Python 3.5 and 3.6 are past their EOL date and support is droppe
  + SECURITY: Replace "weird" characters in receiver's display
  + SECURITY: all past binary signatures are now in Git
  + Use the HKDF primitive from "cryptography"
  + wormhole receive now accepts --allocate-code so that a sender can use --code to send them a file
  + Stream to disk after 10MB on directory receive
  + Handle SSH keys with comments properly
  + Properly parse IPv6 Transit address
* Fri Oct  7 2022 Daniel Garcia <daniel.garcia@suse.com>
- Use %%pytest macro instead of plain pytest command for testing
* Fri Oct  7 2022 Daniel Garcia <daniel.garcia@suse.com>
- Revert previous change, go back to pytest for testing
- Disable test_welcome, that's the only test that fails for some reason for
  python3.8 and python3.9
* Fri Oct  7 2022 Daniel Garcia <daniel.garcia@suse.com>
- Run tests with coverage, using the same tool that is used upstream
* Wed May 18 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/magic-wormhole/magic-wormhole/issues/439
  + python-magic-wormhole-no-mock.patch
* Tue Jan 11 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros dependency
* Wed Jul 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- No longer build for python 3.6: not all dependencies are
  supported (e.g autobahn).
* Mon Mar 22 2021 Matej Cepl <mcepl@suse.com>
- Add missing BR on %%{pythons}
* Wed Aug 19 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.12.0:
  * A command like wormhole send /dev/fd0 can send the contents of the named
    block device (USB stick, SD card, floppy, etc), resulting in a plain file
    on the other side. (#323)
  * Change "accept this file?" default answer from no to yes. (#327 #330 #331)
  * Actually use tempfile for large directory transfers. This fixes a
    five-year old bug which prevents transfers of directories larger than
    available RAM by finally really building the temporary zipfile on
    disk. (#379)
  * Accept 'wss' for TLS-protected relay connections, which default to port
    443 if no other port is accepted. A future release will change the public
    relay to use TLS. (#144)
  * Drop support for python3.4
  * Stall --verify long enough to send the verifier. This fixes a bug when
    both sides use --verify, the receiver uses tab-completion, the sender
    sees the verifier and waits for the user to confirm, but the receiver
    cannot show the verifier (enabling that confirmation) until the sender
    approves the transfer. (#349)
* Wed Mar 25 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the update-alternatives to provide py2 variant too bsc#1152403
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in description.
* Fri May 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.11.2
  * Fix python -m wormhole on py2.
  * Python-3.7 compatibility was fixed.
  * The client version is now sent to the mailbox server for each
    connection.
  Packaging changes:
  * We removed the Rendezvous Server (now named the "Mailbox
    Server") out to a separate package and repository named
    magic-wormhole-mailbox-server.
  * The Dockerfile was removed.
- Launch tests again.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Mar 12 2018 tchvatal@suse.com
- Drop the test sections as the tests require the package to be
  installed
* Mon Mar 12 2018 tchvatal@suse.com
- Properly handle singlespec to allow py2 and py3 build
* Mon Mar 12 2018 tchvatal@suse.com
- Rename to python-*
- Allow python2 build
* Fri Mar  2 2018 avvissu@yandex.by
- Initial package
